from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Directory, Boolean, String

Cuffdiff_V0_1_0 = CommandToolBuilder(tool="cuffdiff", base_command=["cuffdiff"], inputs=[ToolInput(tag="in_output_dir", input_type=Directory(optional=True), prefix="--output-dir", doc=InputDocumentation(doc="write all output files to this directory              [ default:     ./ ]")), ToolInput(tag="in_labels", input_type=Boolean(optional=True), prefix="--labels", doc=InputDocumentation(doc="comma-separated list of condition labels")), ToolInput(tag="in_fdr", input_type=Boolean(optional=True), prefix="--FDR", doc=InputDocumentation(doc="False discovery rate used in testing                  [ default:   0.05 ]")), ToolInput(tag="in_mask_file", input_type=Boolean(optional=True), prefix="--mask-file", doc=InputDocumentation(doc="ignore all alignment within transcripts in this file  [ default:   NULL ]")), ToolInput(tag="in_contrast_file", input_type=Boolean(optional=True), prefix="--contrast-file", doc=InputDocumentation(doc="Perform the constrasts specified in this file         [ default:   NULL ]")), ToolInput(tag="in_frag_bias_correct", input_type=Boolean(optional=True), prefix="--frag-bias-correct", doc=InputDocumentation(doc="use bias correction - reference fasta required        [ default:   NULL ]")), ToolInput(tag="in_multi_read_correct", input_type=Boolean(optional=True), prefix="--multi-read-correct", doc=InputDocumentation(doc="use 'rescue method' for multi-reads                   [ default:  FALSE ]")), ToolInput(tag="in_num_threads", input_type=Boolean(optional=True), prefix="--num-threads", doc=InputDocumentation(doc="number of threads used during quantification          [ default:      1 ]")), ToolInput(tag="in_no_diff", input_type=Boolean(optional=True), prefix="--no-diff", doc=InputDocumentation(doc="Don't generate differential analysis files            [ default:  FALSE ]")), ToolInput(tag="in_no_js_tests", input_type=Boolean(optional=True), prefix="--no-js-tests", doc=InputDocumentation(doc="Don't perform isoform switching tests                 [ default:  FALSE ]")), ToolInput(tag="in_time_series", input_type=Boolean(optional=True), prefix="--time-series", doc=InputDocumentation(doc="treat samples as a time-series                        [ default:  FALSE ]")), ToolInput(tag="in_library_type", input_type=Boolean(optional=True), prefix="--library-type", doc=InputDocumentation(doc="Library prep used for input reads                     [ default:  below ]")), ToolInput(tag="in_dispersion_method", input_type=Boolean(optional=True), prefix="--dispersion-method", doc=InputDocumentation(doc="Method used to estimate dispersion models             [ default:  below ]")), ToolInput(tag="in_library_norm_method", input_type=Boolean(optional=True), prefix="--library-norm-method", doc=InputDocumentation(doc="Method used to normalize library sizes                [ default:  below ]")), ToolInput(tag="in_frag_len_mean", input_type=Boolean(optional=True), prefix="--frag-len-mean", doc=InputDocumentation(doc="average fragment length (unpaired reads only)         [ default:    200 ]")), ToolInput(tag="in_frag_len_std_dev", input_type=Boolean(optional=True), prefix="--frag-len-std-dev", doc=InputDocumentation(doc="fragment length std deviation (unpaired reads only)   [ default:     80 ]")), ToolInput(tag="in_min_alignment_count", input_type=Boolean(optional=True), prefix="--min-alignment-count", doc=InputDocumentation(doc="minimum number of alignments in a locus for testing   [ default:   10 ]")), ToolInput(tag="in_max_mle_iterations", input_type=Boolean(optional=True), prefix="--max-mle-iterations", doc=InputDocumentation(doc="maximum iterations allowed for MLE calculation        [ default:   5000 ]")), ToolInput(tag="in_compatible_hits_norm", input_type=Boolean(optional=True), prefix="--compatible-hits-norm", doc=InputDocumentation(doc="count hits compatible with reference RNAs only        [ default:   TRUE ]")), ToolInput(tag="in_total_hits_norm", input_type=Boolean(optional=True), prefix="--total-hits-norm", doc=InputDocumentation(doc="count all hits for normalization                      [ default:  FALSE ]")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="log-friendly verbose processing (no progress bar)     [ default:  FALSE ]")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="log-friendly quiet processing (no progress bar)       [ default:  FALSE ]")), ToolInput(tag="in_seed", input_type=Boolean(optional=True), prefix="--seed", doc=InputDocumentation(doc="value of random number generator seed                 [ default:      0 ]")), ToolInput(tag="in_no_update_check", input_type=Boolean(optional=True), prefix="--no-update-check", doc=InputDocumentation(doc="do not contact server to check for update availability[ default:  FALSE ]")), ToolInput(tag="in_emit_count_tables", input_type=Boolean(optional=True), prefix="--emit-count-tables", doc=InputDocumentation(doc="print count tables used to fit overdispersion         [    DEPRECATED   ]")), ToolInput(tag="in_max_bundle_frags", input_type=Boolean(optional=True), prefix="--max-bundle-frags", doc=InputDocumentation(doc="maximum fragments allowed in a bundle before skipping [ default: 500000 ]")), ToolInput(tag="in_num_frag_count_draws", input_type=Boolean(optional=True), prefix="--num-frag-count-draws", doc=InputDocumentation(doc="Number of fragment generation samples                 [ default:    100 ]")), ToolInput(tag="in_num_frag_assign_draws", input_type=Boolean(optional=True), prefix="--num-frag-assign-draws", doc=InputDocumentation(doc="Number of fragment assignment samples per generation  [ default:     50 ]")), ToolInput(tag="in_max_frag_multi_hits", input_type=Boolean(optional=True), prefix="--max-frag-multihits", doc=InputDocumentation(doc="Maximum number of alignments allowed per fragment     [ default: unlim  ]")), ToolInput(tag="in_min_outlier_p", input_type=Boolean(optional=True), prefix="--min-outlier-p", doc=InputDocumentation(doc="Min replicate p value to admit for testing            [    DEPRECATED   ]")), ToolInput(tag="in_min_reps_for_js_test", input_type=Boolean(optional=True), prefix="--min-reps-for-js-test", doc=InputDocumentation(doc="Replicates needed for relative isoform shift testing  [ default:      3 ]")), ToolInput(tag="in_no_effective_length_correction", input_type=Boolean(optional=True), prefix="--no-effective-length-correction", doc=InputDocumentation(doc="No effective length correction                  [ default:  FALSE ]")), ToolInput(tag="in_no_length_correction", input_type=Boolean(optional=True), prefix="--no-length-correction", doc=InputDocumentation(doc="No length correction                                  [ default:  FALSE ]")), ToolInput(tag="in_upper_quartile_norm", input_type=Boolean(optional=True), prefix="--upper-quartile-norm", doc=InputDocumentation(doc="Deprecated, use --library-norm-method                 [    DEPRECATED   ]")), ToolInput(tag="in_geometric_norm", input_type=Boolean(optional=True), prefix="--geometric-norm", doc=InputDocumentation(doc="Deprecated, use --library-norm-method                 [    DEPRECATED   ]")), ToolInput(tag="in_raw_mapped_norm", input_type=Boolean(optional=True), prefix="--raw-mapped-norm", doc=InputDocumentation(doc="Deprecated, use --library-norm-method                 [    DEPRECATED   ]")), ToolInput(tag="in_poisson_dispersion", input_type=Boolean(optional=True), prefix="--poisson-dispersion", doc=InputDocumentation(doc="Deprecated, use --dispersion-method                   [    DEPRECATED   ]")), ToolInput(tag="in_read_skip_fraction", input_type=Boolean(optional=True), prefix="--read-skip-fraction", doc=InputDocumentation(doc="Skip a random subset of reads this size               [ default:    0.0 ]")), ToolInput(tag="in_no_read_pairs", input_type=Boolean(optional=True), prefix="--no-read-pairs", doc=InputDocumentation(doc="Break all read pairs                                  [ default:  FALSE ]")), ToolInput(tag="in_trim_read_length", input_type=Boolean(optional=True), prefix="--trim-read-length", doc=InputDocumentation(doc="Trim reads to be this long (keep 5' end)              [ default:   none ]")), ToolInput(tag="in_no_scv_correction", input_type=Boolean(optional=True), prefix="--no-scv-correction", doc=InputDocumentation(doc="Disable SCV correction                                [ default:  FALSE ]")), ToolInput(tag="in_ff_first_strand", input_type=String(), position=0, doc=InputDocumentation(doc="ff-secondstrand")), ToolInput(tag="in_ff_un_stranded", input_type=String(), position=1, doc=InputDocumentation(doc="fr-firststrand")), ToolInput(tag="in_fr_second_strand", input_type=String(), position=2, doc=InputDocumentation(doc="fr-unstranded (default)")), ToolInput(tag="in_trans_frags", input_type=String(), position=3, doc=InputDocumentation(doc="Supported dispersion methods:")), ToolInput(tag="in_blind", input_type=String(), position=4, doc=InputDocumentation(doc="per-condition")), ToolInput(tag="in_poisson", input_type=String(), position=5, doc=InputDocumentation(doc="pooled (default)")), ToolInput(tag="in_classic_fp_km", input_type=String(), position=0, doc=InputDocumentation(doc="geometric (default)")), ToolInput(tag="in_geometric", input_type=String(), position=1, doc=InputDocumentation(doc="quartile"))], outputs=[ToolOutput(tag="out_output_dir", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_output_dir", type_hint=File()), doc=OutputDocumentation(doc="write all output files to this directory              [ default:     ./ ]"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Cuffdiff_V0_1_0().translate("wdl", allow_empty_container=True)

